<#if isPolled == true>
/**
 * TIMER Switch Frequency - Polling Example Driver File
 * 
 <#if isTestMode == true>
 * @file uc2.c
 *
 * @addtogroup timer-switch-frequency-example TIMER Switch Frequency
 <#else>
 * @file timer_example.c
 * 
 * @addtogroup timer_example
  </#if>
 * 
 * @brief This is the generated example implementation for TIMER Switch Frequency - Polled driver.
 *
 * @version TIMER Switch Frequency - Polled Example Version 2.0.0
*/
<#elseif isCallback == true>
/**
 * TIMER Switch Frequency - Callback Example Driver File
 * 
 <#if isTestMode == true>
 * @file uc2.c
 *
 * @addtogroup timer-switch-frequency-example TIMER Switch Frequency
 <#else>
 * @file timer_example.c
 </#if>
 * 
 * @addtogroup timer_example
 * 
 * @brief This is the generated example implementation for TIMER Switch Frequency - Callback driver.
 *
 * @version TIMER Switch Frequency - Callback Example Version 2.0.0
*/
</#if>
${disclaimer}

<#if isPolled == true>
/* Use Case 2 - Polled implementation. Copy this code to your project source, e.g., to main.c  */
<#elseif isCallback == true>
/* Use Case 2 - Callback implementation. Copy this code to your project source, e.g., to main.c  */
</#if>
<#if isTestMode == false>
/* ------------------------------------------------------------------
</#if>
<#if isTestMode == true>
#include "../../system/system.h"
#include "uc2.h"

static void Timer_Callback(void);
static void Button_Callback(void);
static void Timer_ChangeFrequency(void);

static const struct TIMER_INTERFACE *Timer = &TimerX;
static volatile bool changePeriod = false;
static volatile bool buttonPressed = false;

// TODO: Go to Header Files/MCC Generated Files/timer/tmrx.h - replace x with TMRx_CLOCK_FREQ defined. ----------------------
#define MS_TO_TICKS(ms) (((31000UL * (ms)) / 1000UL) - 1UL)   
#define LED_100_MS (MS_TO_TICKS(100UL))           
#define LED_500_MS (MS_TO_TICKS(500UL))

static void TIMER_Callback_100ms(void);
static void TIMER_Callback_500ms(void);
static void BUTTON_Callback(void);
static void Timer_ChangeFrequency(void);

<#else>

#include "mcc_generated_files/system/system.h"

// TODO: Replace TimerX with name of const struct TIMER_INTERFACE, from MCC Generated Files > timer > tmrx.c  ----------
static const struct TIMER_INTERFACE *Timer = &TimerX;  
static volatile bool changePeriod = false;
static volatile bool buttonPressed = false;

// TODO: Go to Header Files/MCC Generated Files/timer/tmrx.h - replace x with TMRx_CLOCK_FREQ defined. ----------------------
#define MS_TO_TICKS(ms) (((TMRx_CLOCK_FREQ * (ms)) / 1000UL) - 1UL)   
#define LED_100_MS (MS_TO_TICKS(100UL))           
#define LED_500_MS (MS_TO_TICKS(500UL))

static void TIMER_Callback_100ms(void);
static void TIMER_Callback_500ms(void);
static void BUTTON_Callback(void);
static void Timer_ChangeFrequency(void);

</#if>

void TIMER_Callback_100ms(void)
{
    IO_LED_Toggle();
}

void TIMER_Callback_500ms(void)
{
    IO_LED_Toggle();
}

static void Button_Callback(void)
{
    if (!buttonPressed)
    {
        buttonPressed = true;
        changePeriod = true;
    }
}

static void Timer_ChangeFrequency(void)
{
    static volatile bool period100ms = false; // Set initial period to 500ms

    Timer->Stop();
    if (period100ms)
    {
        Timer->PeriodSet(LED_100_MS);
        Timer->TimeoutCallbackRegister(TIMER_Callback_100ms);  // Change timer callback
        period100ms = false;
    }
    else
    {
        Timer->PeriodSet(LED_500_MS);
        Timer->TimeoutCallbackRegister(TIMER_Callback_500ms);  // Change timer callback
        period100ms = true;
    }
    Timer->Start();
}

<#if isPolled == true>
<#if isTestMode == true>
void TIMER_Example2(void)
<#else>
int main(void)
</#if>
{
    SYSTEM_Initialize();
    Timer->TimeoutCallbackRegister(TIMER_Callback_100ms);
<#if InterfaceType == "Interface_PIC18">
    INTERRUPT_GlobalInterruptEnable();
<#elseif InterfaceType == "Interface_PIC16">
    INTERRUPT_GlobalInterruptEnable();
    INTERRUPT_PeripheralInterruptEnable();
</#if>

    while (1)
    {
        Timer->Tasks();
        if (!IO_BUTTON_GetValue())
        {
            Timer_ChangeFrequency();
            changePeriod = false;
        }

        // Reset button pressed flag after debounce period
        if (buttonPressed && IO_BUTTON_GetValue())
        {
            buttonPressed = false;
        }
    }
}
<#elseif isCallback == true>
<#if isTestMode == true>
void TIMER_Example2(void)
<#else>
int main(void)
</#if>
{
    SYSTEM_Initialize();
    Timer->TimeoutCallbackRegister(TIMER_Callback_100ms);
    IO_BUTTON_SetInterruptHandler(Button_Callback); // Select for BUTTON pin you are using
<#if InterfaceType == "Interface_PIC18">
    INTERRUPT_GlobalInterruptEnable();
<#elseif InterfaceType == "Interface_PIC16">
    INTERRUPT_GlobalInterruptEnable();
    INTERRUPT_PeripheralInterruptEnable();
</#if>

    while (1)
    {
        if (changePeriod)
        {
            Timer_ChangeFrequency();
            changePeriod = false;
        }

        // Reset button pressed flag after debounce period
        if (buttonPressed && IO_BUTTON_GetValue())
        {
            buttonPressed = false;
        }
    }
}
</#if>
<#if isTestMode == false>
------------------------------------------------------------------ */
</#if>
/**
 End of File
*/